NotificarePush class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

allowedUI Future<bool>
Indicates whether the device is capable of receiving remote notifications.
no setter
hasRemoteNotificationsEnabled Future<bool>
Indicates whether remote notifications are enabled.
no setter
onFailedToRegisterForRemoteNotifications Stream<String>
Called when the app encounters an error during the registration process for push notifications.
no setter
onNotificationActionOpened Stream<NotificareNotificationActionOpenedEvent>
Called when a push notification action is opened by the user.
no setter
onNotificationInfoReceived Stream<NotificareNotificationReceivedEvent>
Called when a push notification is received.
no setter
onNotificationOpened Stream<NotificareNotification>
Called when a push notification is opened by the user.
no setter
onNotificationSettingsChanged Stream<bool>
Called when the notification settings are changed.
no setter
onShouldOpenNotificationSettings Stream<NotificareNotification?>
Called when a notification prompts the app to open its settings screen.
no setter
onSubscriptionChanged Stream<NotificarePushSubscription?>
Called when the device's push subscription changes.
no setter
onSystemNotificationReceived Stream<NotificareSystemNotification>
Called when a custom system notification is received.
no setter
onUnknownNotificationActionOpened Stream<NotificareUnknownNotificationActionOpenedEvent>
Called when an unknown push notification action is opened by the user.
no setter
onUnknownNotificationOpened Stream<Map<String, dynamic>>
Called when an unknown push notification is opened by the user.
no setter
onUnknownNotificationReceived Stream<Map<String, dynamic>>
Called when an unknown notification is received.
no setter
subscription Future<NotificarePushSubscription?>
Provides the current push subscription token.
no setter
transport Future<NotificareTransport?>
Provides the current push transport information.
no setter

Static Methods

disableRemoteNotifications() Future<void>
Disables remote notifications.
enableRemoteNotifications() Future<void>
Enables remote notifications.
setAuthorizationOptions(List<String> options) Future<void>
Defines the authorization options used when requesting push notification permissions.
setCategoryOptions(List<String> options) Future<void>
Defines the notification category options for custom notification actions.
setPresentationOptions(List<String> options) Future<void>
Defines the presentation options for displaying notifications while the app is in the foreground.