enableRemoteNotifications static method

Future<void> enableRemoteNotifications()

Enables remote notifications.

This function enables remote notifications for the application, allowing push notifications to be received.

Note: Starting with Android 13 (API level 33), this function requires the developer to explicitly request the POST_NOTIFICATIONS permission from the user.

Implementation

static Future<void> enableRemoteNotifications() async {
  await _channel.invokeMapMethod('enableRemoteNotifications');
}