onFailedToRegisterForRemoteNotifications property

Stream<String> get onFailedToRegisterForRemoteNotifications

Called when the app encounters an error during the registration process for push notifications.

It will provide the error that caused the registration to fail.

Implementation

static Stream<String> get onFailedToRegisterForRemoteNotifications {
  return _getEventStream('failed_to_register_for_remote_notifications')
      .map((result) {
    return result as String;
  });
}