onNotificationSettingsChanged property

Stream<bool> get onNotificationSettingsChanged

Called when the notification settings are changed.

It will provide a boolean indicating whether the app is permitted to display notifications. true if notifications are allowed, false if they are restricted by the user.

Implementation

static Stream<bool> get onNotificationSettingsChanged {
  return _getEventStream('notification_settings_changed').map((result) {
    return result as bool;
  });
}