onShouldOpenNotificationSettings property

Stream<NotificareNotification?> get onShouldOpenNotificationSettings

Called when a notification prompts the app to open its settings screen.

It will provide the NotificareNotification that prompted the app to open its settings screen.

Implementation

static Stream<NotificareNotification?> get onShouldOpenNotificationSettings {
  return _getEventStream('should_open_notification_settings').map((result) {
    if (result == null) return null;

    final Map<dynamic, dynamic> json = result;
    return NotificareNotification.fromJson(json.cast());
  });
}