onUnknownNotificationOpened property
Called when an unknown push notification is opened by the user.
It will provide the unknown notification that was opened.
Implementation
static Stream<Map<String, dynamic>> get onUnknownNotificationOpened {
return _getEventStream('unknown_notification_opened').map((result) {
final Map<dynamic, dynamic> json = result;
return json.cast();
});
}